
from pydantic import BaseModel, Field
from typing import List,  Union, Tuple, Iterable, Dict, Any
from typing import AsyncGenerator, Optional, Union, List, Dict

class TranscriptionSettings(BaseModel):
  # Основные настройки задания: транскрипция или перевод
  task: str = "transcribe"        # "transcribe" или "translate"
  
  # Логирование и контроль прогресса (если требуется)
  log_progress: bool = False
  
  batch_size: int = 8
  # Параметры декодирования
  beam_size: int = 7           # размер beam'а (например, 7)
  best_of: int = 10            # количество вариантов для выбора наилучшего
  patience: float = 1.0          # параметр терпения (if applicable)
  length_penalty: float = 1.0       # штраф за длину
  repetition_penalty: float = 1.0     # штраф за повторение
  no_repeat_ngram_size: int = 0      # запрещённый размер n-грамм
  
  # Параметры генерации (temperature можно задать как число или как диапазон вариантов)
  temperature: Union[float, List[float], Tuple[float, ...]] = Field(
    default_factory=lambda: [0, 0.2, 0.4, 0.6, 0.8, 1]
  )
  # Дополнительные пороги и ограничения
  compression_ratio_threshold: Optional[float] = 2.4
  log_prob_threshold: Optional[float] = -1.0
  no_speech_threshold: Optional[float] = 0.6
  condition_on_previous_text: bool = True
  prompt_reset_on_temperature: float = 0.5
  
  # Настройки для корректировки начального текста
  initial_prompt: Optional[Union[str, Iterable[int]]] = None # Можно передавать строку или последовательность токенов
  prefix: Optional[str] = None
  suppress_blank: bool = True
  suppress_tokens: Optional[List[int]] = Field(default_factory=lambda: [-1])
  
  # Управление таймингом и разбиением (timestamps)
  without_timestamps: bool = False
  max_initial_timestamp: float = 1.0
  word_timestamps: bool = True
  prepend_punctuations: str = "\"'“¿([{-"  # символы, которые будут добавляться перед словами, если требуется
  append_punctuations: str = "\"'.。,，!！?？:：”)]}、" # символы для окончания
  
  # Многоязычность и параметры VAD (голосовой активити детектор)
  multilingual: bool = False
  vad_filter: bool = True
  vad_parameters: Optional[Dict[str, Any]] = None  # сюда можно передать словарь с дополнительными настройками VAD
  
  # Дополнительные ограничения на выдачу
  max_new_tokens: Optional[int] = None
  chunk_length: Optional[int] = None
  clip_timestamps: Union[str, List[float]] = "0"
  hallucination_silence_threshold: Optional[float] = None
  hotwords: Optional[str] = None
  language_detection_threshold: Optional[float] = 0.5
  language_detection_segments: int = 1
  
  # Язык модели (если не задан – будет использован русский)
  language: str = "ru"
  emotional: bool = False


class ProcessingSettings(BaseModel):
    mode: str = "both"
    task: str = "transcribe"
    format_output: str = "json"
    async_process: bool = False
    transcription_settings: dict = {}
